@@ -492,7 +492,7 @@ class DataTransformerForm(BaseInlineFormSet):
                                                              extra=1, exclude=['updated_at', 'created_at'],
                                                              form=self.__class__)
         form.nested_data_transformer_form = dataTransformerInlineFormset(
-            instance=self.instance.datatransformer_set,
+            instance=self.instance,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             extra=1)
@@ -524,11 +524,44 @@ class DataTransform(forms.Form):
 
     data_transformer_parent = forms.CharField(required=False,
                                               widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    type = forms.CharField(required=True,
+    type = forms.CharField(required=False,
                            widget=forms.TextInput(attrs={'class': 'form-control'}))
 
 
+
+    # def __init__(self, *args, **kwargs):
+    #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        super(DataTransform, self).__init__(*args, **kwargs)
+        # dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+        #                                                      fk_name='data_transformer_parent',
+        #                                                      extra=1, exclude=['updated_at', 'created_at'],
+        #                                                      form=self.__class__)
+        # self.nested_data_transformer_form = dataTransformerInlineFormset(
+        #     instance=self,
+        #     data=self.data if self.is_bound else None,
+        #     files=self.files if self.is_bound else None,
+        #     extra=1)
+        #
+        # self.nested_constants_form = DataConstantsTransformerInlineFormset(
+        #     instance=self,
+        #     data=self.data if self.is_bound else None,
+        #     files=self.files if self.is_bound else None,
+        #     extra=1)
+        #
+        # self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+        #     instance=self,
+        #     data=self.data if self.is_bound else None,
+        #     files=self.files if self.is_bound else None,
+        #     extra=1)
+        #
+        # self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+        #     instance=self,
+        #     data=self.data if self.is_bound else None,
+        #     files=self.files if self.is_bound else None,
+        #     extra=1)
+
     class Meta:
         model = DataTransformer
-        fields = ("__all__")
+        fields = ['id','accessory','data_transformer_parent','type']
 # DataTransformerFormset = form_factory(DataTransformer,formset=DataTransformerForm)
