@@ -4,6 +4,10 @@ from data.models.models import CalibrationConstants, Calibration, Channel, Acces
     DHT22, MCP3008, ModProbe, VEML7700, Hardware, Hub, SPIIo, SerialIo, PwmIo, I2cIo, DeviceFileIo, MCPAnalogIo, \
     PiPicoAnalogIo, PiPicoACAnalogIo, PiGpio, DataTransformer
 
+class RecursiveField(serializers.Serializer):
+    def to_representation(self, value):
+        serializer = self.parent.parent.__class__(value, context=self.context)
+        return serializer.data
 
 class CalibrationConstantsSerializer(serializers.ModelSerializer):
     class Meta:
@@ -43,8 +47,7 @@ class AccessorySerializer(serializers.ModelSerializer):
 
 
 class DataTransformerSerializer(serializers.ModelSerializer):
-    # channels = ChannelSerializer(source='channel_set', many=True)
-    calibration = CalibrationSerializer(source='calibration_set', many=True, read_only=False)
+    data_transformer_child = RecursiveField(many=True)
 
     class Meta:
         model = DataTransformer
