@@ -390,7 +390,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         calibration_form = CalibrationForm(initial={'accessory': accessory})
 
         if accessory.has_data_transformer:
-            data_transformer = accessory.data_transformer
+            data_transformer = accessory.datatransformer
             datatransformerset = formset_factory(DataTransform(instance=data_transformer), formset=DataTransformerForm, extra=0)
             formset = datatransformerset(instance=data_transformer)
         else:
@@ -398,7 +398,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
             data_transformer.accessory = accessory
             data_transformer.save()
             accessory = Accessory.objects.get(**kwargs)
-            data_transformer = accessory.data_transformer
+            data_transformer = accessory.datatransformer
             datatransformerset = formset_factory(DataTransform(instance=data_transformer), formset=DataTransformerForm, extra=0)
             formset = datatransformerset(instance=data_transformer)
 
